@@ -38,6 +38,8 @@ import android.os.Bundle;
 import android.os.Handler;
 import android.os.IBinder;
 import android.os.Message;
+import android.support.annotation.NonNull;
+import android.support.design.internal.NavigationMenuView;
 import android.support.design.widget.NavigationView;
 import android.support.v4.app.Fragment;
 import android.support.v4.app.FragmentManager;
@@ -53,9 +55,11 @@ import android.view.MenuInflater;
 import android.view.MenuItem;
 import android.view.SubMenu;
 import android.view.View;
+import android.view.ViewGroup;
 import android.view.Window;
 import android.view.WindowManager;
 import android.widget.FilterQueryProvider;
+import android.widget.ImageButton;
 import android.widget.ProgressBar;
 import android.widget.TextView;
 
@@ -127,7 +131,6 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
     private boolean mScanNeeded = false;
 
     private Handler mHandler = new MainActivityHandler(this);
-    private int mFocusedPrior = 0;
     private int mActionBarIconId = -1;
     Menu mMenu;
     private SearchView mSearchView;
@@ -202,6 +205,16 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                 if (getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder) instanceof MediaBrowserFragment)
                     ((MediaBrowserFragment) getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder)).setReadyToDisplay(true);
             }
+
+            // Hack to make navigation drawer browsable with DPAD.
+            // see https://code.google.com/p/android/issues/detail?id=190975
+            // and http://stackoverflow.com/a/34658002/3485324
+            @Override
+            public void onDrawerOpened(View drawerView) {
+                super.onDrawerOpened(drawerView);
+                if(mNavigationView.requestFocus())
+                    ((NavigationMenuView)mNavigationView.getFocusedChild()).setDescendantFocusability(ViewGroup.FOCUS_AFTER_DESCENDANTS);
+            }
         };
 
         // Set the drawer toggle as the DrawerListener
@@ -229,7 +242,6 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
 
     private void setupNavigationView() {
         mNavigationView = (NavigationView) findViewById(R.id.navigation);
-        mNavigationView.setNavigationItemSelectedListener(this);
         if (TextUtils.equals(BuildConfig.FLAVOR_target, "chrome")) {
             MenuItem item = mNavigationView.getMenu().findItem(R.id.nav_directories);
             item.setTitle(R.string.open);
@@ -244,17 +256,16 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
 
     @Override
     public void onRequestPermissionsResult(int requestCode,
-                                           String permissions[], int[] grantResults) {
+                                           @NonNull String permissions[], int[] grantResults) {
         switch (requestCode) {
             case Permissions.PERMISSION_STORAGE_TAG:
                 // If request is cancelled, the result arrays are empty.
                 if (grantResults.length > 0
-                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
+                        && grantResults[0] == PackageManager.PERMISSION_GRANTED)
                     forceRefresh(getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder));
-                } else {
+                else
                     Permissions.showStoragePermissionDialog(this, false);
-                }
-                return;
+                break;
             // other 'case' lines to check for other
             // permissions this app might request
         }
@@ -265,6 +276,7 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         super.onPostCreate(savedInstanceState);
         // Sync the toggle state after onRestoreInstanceState has occurred.
         mDrawerToggle.syncState();
+        setActionBarFocus();
     }
 
     @TargetApi(Build.VERSION_CODES.HONEYCOMB)
@@ -277,14 +289,17 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
     protected void onStart() {
         super.onStart();
 
-        createExtensionServiceConnection();
+          //Deactivated for now
+//        createExtensionServiceConnection();
 
-        cleatBackstackFromExtension();
+        mNavigationView.setNavigationItemSelectedListener(this);
+        clearBackstackFromClass(ExtensionBrowser.class);
     }
 
     @Override
     protected void onStop() {
         super.onStop();
+        mNavigationView.setNavigationItemSelectedListener(null);
         if (mExtensionServiceConnection != null) {
             unbindService(mExtensionServiceConnection);
             mExtensionServiceConnection = null;
@@ -402,8 +417,6 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         SharedPreferences.Editor editor = mSettings.edit();
         editor.putInt("fragment_id", mCurrentFragmentId);
         Util.commitPreferences(editor);
-
-        mFocusedPrior = 0;
     }
 
     protected void onSaveInstanceState(Bundle outState) {
@@ -422,8 +435,6 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
     public void onBackPressed() {
         /* Close the menu first */
         if(mDrawerLayout.isDrawerOpen(mNavigationView)) {
-            if (mFocusedPrior != 0)
-                requestFocusOnSearch();
             mDrawerLayout.closeDrawer(mNavigationView);
             return;
         }
@@ -578,7 +589,7 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
 
         if (current instanceof NetworkBrowserFragment &&
                 !((NetworkBrowserFragment)current).isRootDirectory()) {
-            MenuItemCompat.setShowAsAction(menu.findItem(R.id.ml_menu_search), MenuItem.SHOW_AS_ACTION_IF_ROOM);
+            MenuItemCompat.setShowAsAction(menu.findItem(R.id.ml_menu_search), MenuItemCompat.SHOW_AS_ACTION_IF_ROOM);
             item = menu.findItem(R.id.ml_menu_save);
             item.setVisible(true);
             String mrl = ((BaseBrowserFragment)current).mMrl;
@@ -601,6 +612,7 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
      */
     @Override
     public boolean onOptionsItemSelected(MenuItem item) {
+        UiTools.setKeyboardVisibility(mDrawerLayout, false);
 
         // Current fragment loaded
         Fragment current = getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder);
@@ -693,94 +705,10 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         }
     }
 
-    public void setMenuFocusDown(boolean idIsEmpty, int id) {
-        if (mMenu == null)
+    private void setActionBarFocus() {
+        View v = ((ViewGroup)findViewById(R.id.main_toolbar)).getChildAt(0);
+        if (v == null || ! (v instanceof ImageButton))
             return;
-        //Save menu items ids for focus control
-        final int[] menu_controls = new int[mMenu.size()+1];
-        for (int i = 0 ; i < mMenu.size() ; i++){
-            menu_controls[i] = mMenu.getItem(i).getItemId();
-        }
-        menu_controls[mMenu.size()] = mActionBarIconId;
-        /*menu_controls = new int[]{R.id.ml_menu_search,
-            R.id.ml_menu_open_mrl, R.id.ml_menu_sortby,
-            R.id.ml_menu_last_playlist, R.id.ml_menu_refresh,
-            mActionBarIconId};*/
-        int pane = mSlidingPane.getState();
-        for(int r : menu_controls) {
-            View v = findViewById(r);
-            if (v != null) {
-                if (!idIsEmpty)
-                    v.setNextFocusDownId(id);
-                else {
-                    if (pane ==  mSlidingPane.STATE_CLOSED) {
-                        v.setNextFocusDownId(R.id.play_pause);
-                    } else if (pane == mSlidingPane.STATE_OPENED) {
-                        v.setNextFocusDownId(R.id.header_play_pause);
-                    } else if (pane ==
-                            mSlidingPane.STATE_OPENED_ENTIRELY) {
-                        v.setNextFocusDownId(r);
-                    }
-                }
-            }
-        }
-    }
-
-    public void setSearchAsFocusDown(boolean idIsEmpty, View parentView, int id) {
-        View playPause = findViewById(R.id.header_play_pause);
-
-        if (!idIsEmpty) {
-            View list;
-            int pane = mSlidingPane.getState();
-
-            if (parentView == null)
-                list = findViewById(id);
-            else
-                list = parentView.findViewById(id);
-
-            if (list != null) {
-                if (pane == mSlidingPane.STATE_OPENED_ENTIRELY) {
-                    list.setNextFocusDownId(id);
-                } else if (pane == mSlidingPane.STATE_OPENED) {
-                    list.setNextFocusDownId(R.id.header_play_pause);
-                    playPause.setNextFocusUpId(id);
-                }
-            }
-        } else {
-            playPause.setNextFocusUpId(R.id.ml_menu_search);
-        }
-    }
-
-    // Note. onKeyDown will not occur while moving within a list
-    @Override
-    public boolean onKeyDown(int keyCode, KeyEvent event) {
-        //Filter for LG devices, see https://code.google.com/p/android/issues/detail?id=78154
-        if ((keyCode == KeyEvent.KEYCODE_MENU) &&
-                (Build.VERSION.SDK_INT <= 16) &&
-                (Build.MANUFACTURER.compareTo("LGE") == 0)) {
-            return true;
-        }
-        if (mFocusedPrior == 0)
-            setMenuFocusDown(true, 0);
-        if (getCurrentFocus() != null)
-            mFocusedPrior = getCurrentFocus().getId();
-        return super.onKeyDown(keyCode, event);
-    }
-
-    // Note. onKeyDown will not occur while moving within a list
-    @TargetApi(Build.VERSION_CODES.HONEYCOMB)
-    @Override
-    public boolean onKeyUp(int keyCode, KeyEvent event) {
-        //Filter for LG devices, see https://code.google.com/p/android/issues/detail?id=78154
-        if ((keyCode == KeyEvent.KEYCODE_MENU) &&
-                (Build.VERSION.SDK_INT <= 16) &&
-                (Build.MANUFACTURER.compareTo("LGE") == 0)) {
-            openOptionsMenu();
-            return true;
-        }
-        View v = getCurrentFocus();
-        if (v == null)
-            return super.onKeyUp(keyCode, event);
         if ((mActionBarIconId == -1) &&
                 (v.getId() == -1)  &&
                 (v.getNextFocusDownId() == -1) &&
@@ -798,6 +726,31 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
             if (findViewById(R.id.ml_menu_search) != null)
                 findViewById(R.id.ml_menu_search).setNextFocusLeftId(mActionBarIconId);
         }
+    }
+
+    // Note. onKeyDown will not occur while moving within a list
+    @Override
+    public boolean onKeyDown(int keyCode, KeyEvent event) {
+        //Filter for LG devices, see https://code.google.com/p/android/issues/detail?id=78154
+        if ((keyCode == KeyEvent.KEYCODE_MENU) &&
+                (Build.VERSION.SDK_INT <= 16) &&
+                (Build.MANUFACTURER.compareTo("LGE") == 0)) {
+            return true;
+        }
+        return super.onKeyDown(keyCode, event);
+    }
+
+    // Note. onKeyDown will not occur while moving within a list
+    @TargetApi(Build.VERSION_CODES.HONEYCOMB)
+    @Override
+    public boolean onKeyUp(int keyCode, KeyEvent event) {
+        //Filter for LG devices, see https://code.google.com/p/android/issues/detail?id=78154
+        if ((keyCode == KeyEvent.KEYCODE_MENU) &&
+                (Build.VERSION.SDK_INT <= 16) &&
+                (Build.MANUFACTURER.compareTo("LGE") == 0)) {
+            openOptionsMenu();
+            return true;
+        }
         return super.onKeyUp(keyCode, event);
     }
 
@@ -825,11 +778,11 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                     ma.mInfoLayout.setVisibility(View.VISIBLE);
                     break;
                 case ACTIVITY_SHOW_PROGRESSBAR:
-                    ma.setSupportProgressBarIndeterminateVisibility(true);
+                    ma.mInfoProgress.setVisibility(View.VISIBLE);
                     ma.getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
                     break;
                 case ACTIVITY_HIDE_PROGRESSBAR:
-                    ma.setSupportProgressBarIndeterminateVisibility(false);
+                    ma.mInfoProgress.setVisibility(View.GONE);
                     ma.getWindow().clearFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
                     break;
                 case ACTIVITY_SHOW_TEXTINFO:
@@ -844,14 +797,10 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                     /* Cancel any upcoming visibility change */
                         removeMessages(ACTIVITY_SHOW_INFOLAYOUT);
                         ma.mInfoLayout.setVisibility(View.GONE);
-                    }
-                    else {
+                    } else {
                     /* Slightly delay the appearance of the progress bar to avoid unnecessary flickering */
-                        if (!hasMessages(ACTIVITY_SHOW_INFOLAYOUT)) {
-                            Message m = new Message();
-                            m.what = ACTIVITY_SHOW_INFOLAYOUT;
-                            sendMessageDelayed(m, 300);
-                        }
+                        if (!hasMessages(ACTIVITY_SHOW_INFOLAYOUT))
+                            sendEmptyMessageDelayed(ACTIVITY_SHOW_INFOLAYOUT, 300);
                     }
                     break;
             }
@@ -893,6 +842,9 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         if(item == null)
             return false;
 
+        getSupportActionBar().setTitle(null); //clear title
+        getSupportActionBar().setSubtitle(null); //clear subtitle
+
         int id = item.getItemId();
         FragmentManager fm = getSupportFragmentManager();
         Fragment current = fm.findFragmentById(R.id.fragment_placeholder);
@@ -904,13 +856,21 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
             if (mExtensionServiceConnection != null)
                 mExtensionManagerService.disconnect();
 
-            if(current == null || (item != null && mCurrentFragmentId == id)) { /* Already selected */
-                if (mFocusedPrior != 0)
-                    requestFocusOnSearch();
+            if (current == null) {
                 mDrawerLayout.closeDrawer(mNavigationView);
                 return false;
             }
 
+            if(mCurrentFragmentId == id) { /* Already selected */
+                // Go back at root level of current browser
+                if (current instanceof BaseBrowserFragment && !((BaseBrowserFragment) current).isRootDirectory()) {
+                    clearBackstackFromClass(current.getClass());
+                } else {
+                    mDrawerLayout.closeDrawer(mNavigationView);
+                    return false;
+                }
+            }
+
             String tag = getTag(id);
             switch (id){
                 case R.id.nav_about:
@@ -940,9 +900,6 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                     ft.addToBackStack(getTag(mCurrentFragmentId));
                     ft.commit();
                     mCurrentFragmentId = id;
-
-                    if (mFocusedPrior != 0)
-                        requestFocusOnSearch();
             }
         }
         mNavigationView.setCheckedItem(mCurrentFragmentId);
@@ -950,12 +907,13 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
         return true;
     }
 
-    private void cleatBackstackFromExtension() {
+    private void clearBackstackFromClass(Class clazz) {
         FragmentManager fm = getSupportFragmentManager();
         Fragment current = getSupportFragmentManager()
                 .findFragmentById(R.id.fragment_placeholder);
-        while (current instanceof ExtensionBrowser) {
-            fm.popBackStackImmediate();
+        while (clazz.isInstance(current)) {
+            if (!fm.popBackStackImmediate())
+                break;
             current = getSupportFragmentManager()
                     .findFragmentById(R.id.fragment_placeholder);
         }
@@ -981,10 +939,4 @@ public class MainActivity extends AudioPlayerContainerActivity implements Filter
                 return ID_VIDEO;
         }
     }
-
-    private void requestFocusOnSearch() {
-        View search = findViewById(R.id.ml_menu_search);
-        if (search != null)
-            search.requestFocus();
-    }
 }
