@@ -55,13 +55,14 @@ import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.gui.dialogs.SavePlaylistDialog;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.view.ContextMenuRecyclerView;
-import org.videolan.vlc.gui.view.DividerItemDecoration;
 import org.videolan.vlc.gui.view.SwipeRefreshLayout;
 import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.media.MediaDatabase;
 import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.media.MediaWrapper;
+import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.FileUtils;
+import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.WeakHandler;
 
@@ -141,7 +142,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         mEmptyView = (TextView) v.findViewById(android.R.id.empty);
         mFAB = (FloatingActionButton) v.findViewById(R.id.fab_add_custom_dir);
         mLayoutManager = new LinearLayoutManager(getActivity());
-        mRecyclerView.addItemDecoration(new DividerItemDecoration(VLCApplication.getAppContext(), DividerItemDecoration.VERTICAL_LIST));
         mRecyclerView.setLayoutManager(mLayoutManager);
         mRecyclerView.setAdapter(mAdapter);
         mRecyclerView.addOnScrollListener(mScrollListener);
@@ -194,6 +194,18 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             return mCurrentMedia != null ? mCurrentMedia.getTitle() : mMrl;
     }
 
+    public String getSubTitle(){
+        if (mRoot)
+            return null;
+        String mrl = Strings.removeFileProtocole(mMrl);
+        if (!TextUtils.isEmpty(mrl)) {
+            if (this instanceof FileBrowserFragment && mrl.startsWith(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY))
+                mrl = getString(R.string.internal_memory)+mrl.substring(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY.length());
+            mrl = Uri.decode(mrl).replaceAll("://", " ").replaceAll("/", " > ");
+        }
+        return mCurrentMedia != null ? mrl : null;
+    }
+
     @Override
     protected void display() {
         if (!mReadyToDisplay) {
@@ -232,7 +244,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         mAdapter.addItem(media, mReadyToDisplay && mRoot, false);
         if (empty && mReadyToDisplay)
             updateEmptyView();
-        if (mRoot && mSwipeRefreshLayout.isRefreshing())
+        if (mRoot && (empty || mSwipeRefreshLayout.isRefreshing()))
             mHandler.sendEmptyMessage(BrowserFragmentHandler.MSG_HIDE_LOADING);
     }
 
@@ -317,7 +329,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         }
         mAdapter.notifyDataSetChanged();
         parseSubDirectories();
-        focusHelper();
         if (mFAB != null) {
             if (mAdapter.getMediaCount() > 0) {
                 mFAB.setVisibility(View.VISIBLE);
@@ -394,15 +405,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         }
     }
 
-    protected void focusHelper() {
-        if (getActivity() == null || !(getActivity() instanceof MainActivity))
-            return;
-        boolean isEmpty = mAdapter.isEmpty();
-        MainActivity main = (MainActivity) getActivity();
-        main.setMenuFocusDown(isEmpty, R.id.network_list);
-        main.setSearchAsFocusDown(isEmpty, getView(), R.id.network_list);
-    }
-
     public void clear(){
         mAdapter.clear();
     }
@@ -450,6 +452,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             menu.findItem(R.id.directory_view_info).setVisible(type == MediaWrapper.TYPE_VIDEO || type == MediaWrapper.TYPE_AUDIO);
             menu.findItem(R.id.directory_view_play_audio).setVisible(type != MediaWrapper.TYPE_AUDIO);
             menu.findItem(R.id.directory_view_add_playlist).setVisible(type == MediaWrapper.TYPE_AUDIO);
+            menu.findItem(R.id.directory_subtitles_download).setVisible(type == MediaWrapper.TYPE_VIDEO  && canWrite);
         }
     }
 
@@ -527,6 +530,9 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 savePlaylistDialog.setArguments(args);
                 savePlaylistDialog.show(fm, "fragment_add_to_playlist");
                 return true;
+            case R.id.directory_subtitles_download:
+                MediaUtils.getSubs(getActivity(), mw);
+                return true;
 //            case R.id.directory_view_hide_media:
 //                try {
 //                    if (new File(mw.getLocation()+"/.nomedia").createNewFile())
