@@ -33,6 +33,7 @@ import android.content.res.TypedArray;
 import android.graphics.Color;
 import android.os.Bundle;
 import android.support.v4.app.DialogFragment;
+import android.support.v4.content.ContextCompat;
 import android.support.v7.preference.PreferenceManager;
 import android.support.v7.widget.GridLayoutManager;
 import android.support.v7.widget.RecyclerView;
@@ -43,6 +44,7 @@ import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
 import android.widget.TextView;
+import android.widget.Toast;
 
 import org.videolan.libvlc.MediaPlayer;
 import org.videolan.vlc.PlaybackService;
@@ -58,12 +60,12 @@ import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Strings;
-import org.videolan.vlc.view.AutoFitRecyclerView;
+import org.videolan.vlc.gui.view.AutoFitRecyclerView;
 
 import java.util.ArrayList;
 import java.util.Calendar;
 
-public class AdvOptionsDialog extends DialogFragment implements View.OnClickListener, View.OnLongClickListener, PlaybackService.Client.Callback, View.OnFocusChangeListener, DialogInterface.OnKeyListener {
+public class AdvOptionsDialog extends DialogFragment implements View.OnClickListener, PlaybackService.Client.Callback, View.OnFocusChangeListener, DialogInterface.OnKeyListener {
 
     public final static String TAG = "VLC/AdvOptionsDialog";
     public static final String MODE_KEY = "mode";
@@ -86,6 +88,8 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     private static final int ID_EQUALIZER = 7 ;
     private static final int ID_SAVE_PLAYLIST = 8 ;
     private static final int ID_POPUP_VIDEO = 9 ;
+    private static final int ID_REPEAT = 10 ;
+    private static final int ID_SHUFFLE = 11 ;
 
     private Activity mActivity;
     private int mTheme;
@@ -102,8 +106,12 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     private TextView mAudioDelay;
     private TextView mSpuDelay;
 
+    private TextView mRepeat;
+    private TextView mShuffle;
+
     private TextView mChaptersTitle;
     private int mTextColor;
+    private static final int FOCUSED_TEXT_COLOR = ContextCompat.getColor(VLCApplication.getAppContext(), R.color.orange300);
     private PlaybackService mService;
 
     private IPlaybackSettingsController mPlaybackController;
@@ -126,6 +134,12 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
         setStyle(DialogFragment.STYLE_NO_FRAME, mTheme);
     }
 
+    @Override
+    public void onPause() {
+        super.onPause();
+        dismiss();
+    }
+
     @Override
     public void onAttach(Activity activity) {
         super.onAttach(activity);
@@ -259,6 +273,11 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     }
 
     public void initPlaybackSpeed () {
+        if (!mService.isSeekable()) {
+            mPlaybackSpeed.setEnabled(false);
+            mPlaybackSpeed.setCompoundDrawablesWithIntrinsicBounds(0,R.drawable.ic_speed_disable, 0, 0);
+            return;
+        }
         if (mService.getRate() == 1.0f) {
             mPlaybackSpeed.setText(null);
             mPlaybackSpeed.setCompoundDrawablesWithIntrinsicBounds(0,
@@ -268,12 +287,6 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             mPlaybackSpeed.setText(Strings.formatRateString(mService.getRate()));
             mPlaybackSpeed.setCompoundDrawablesWithIntrinsicBounds(0, R.drawable.ic_speed_on, 0, 0);
         }
-        mPlaybackSpeed.setEnabled(mService.isSeekable());
-        mPlaybackSpeed.setCompoundDrawablesWithIntrinsicBounds(0,
-                mService.isSeekable()
-                        ? UiTools.getResourceFromAttribute(mActivity, R.attr.ic_speed_normal_style)
-                        : R.drawable.ic_speed_disable,
-                0, 0);
     }
 
     public void initSleep () {
@@ -290,14 +303,14 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     }
 
     private void initSpuDelay() {
-        long spudelay = mService.getSpuDelay() / 1000l;
-        if (spudelay == 0l) {
+        long spudelay = mService.getSpuDelay() / 1000L;
+        if (spudelay == 0L) {
             mSpuDelay.setText(null);
             mSpuDelay.setCompoundDrawablesWithIntrinsicBounds(0,
                     UiTools.getResourceFromAttribute(mActivity, R.attr.ic_subtitledelay),
                     0, 0);
         } else {
-            mSpuDelay.setText(Long.toString(spudelay) + " ms");
+            mSpuDelay.setText(String.format("%s ms", Long.toString(spudelay)));
             mSpuDelay.setCompoundDrawablesWithIntrinsicBounds(0,
                     R.drawable.ic_subtitledelay_on,
                     0, 0);
@@ -305,26 +318,77 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     }
 
     private void initAudioDelay() {
-        long audiodelay = mService.getAudioDelay() / 1000l;
-        if (audiodelay == 0l) {
+        long audiodelay = mService.getAudioDelay() / 1000L;
+        if (audiodelay == 0L) {
             mAudioDelay.setText(null);
             mAudioDelay.setCompoundDrawablesWithIntrinsicBounds(0,
                     UiTools.getResourceFromAttribute(mActivity, R.attr.ic_audiodelay),
                     0, 0);
         } else {
-            mAudioDelay.setText(Long.toString(audiodelay) + " ms");
+            mAudioDelay.setText(String.format("%s ms", Long.toString(audiodelay)));
             mAudioDelay.setCompoundDrawablesWithIntrinsicBounds(0,
                     R.drawable.ic_audiodelay_on,
                     0, 0);
         }
     }
 
+    public void initRepeat() {
+        switch (mService.getRepeatType()) {
+            case PlaybackService.REPEAT_NONE:
+                mRepeat.setCompoundDrawablesWithIntrinsicBounds(0,
+                        UiTools.getResourceFromAttribute(mActivity, R.attr.ic_repeat),
+                        0, 0);
+                break;
+            case PlaybackService.REPEAT_ALL:
+                mRepeat.setCompoundDrawablesWithIntrinsicBounds(0, R.drawable.ic_repeat_all, 0, 0);
+                break;
+            case PlaybackService.REPEAT_ONE:
+                mRepeat.setCompoundDrawablesWithIntrinsicBounds(0, R.drawable.ic_repeat_one, 0, 0);
+                    break;
+        }
+    }
+
+    public void setRepeatMode() {
+        switch (mService.getRepeatType()) {
+            case PlaybackService.REPEAT_NONE:
+                mRepeat.setCompoundDrawablesWithIntrinsicBounds(0, R.drawable.ic_repeat_one, 0, 0);
+                mService.setRepeatType(PlaybackService.REPEAT_ONE);
+                break;
+            case PlaybackService.REPEAT_ONE:
+                if (mService.hasPlaylist()){
+                    mRepeat.setCompoundDrawablesWithIntrinsicBounds(0, R.drawable.ic_repeat_all, 0, 0);
+                    mService.setRepeatType(PlaybackService.REPEAT_ALL);
+                } else {
+                    mRepeat.setCompoundDrawablesWithIntrinsicBounds(0,
+                            UiTools.getResourceFromAttribute(mActivity, R.attr.ic_repeat),
+                            0, 0);
+                    mService.setRepeatType(PlaybackService.REPEAT_NONE);
+                }
+                break;
+            case PlaybackService.REPEAT_ALL:
+                mRepeat.setCompoundDrawablesWithIntrinsicBounds(0,
+                        UiTools.getResourceFromAttribute(mActivity, R.attr.ic_repeat),
+                        0, 0);
+                mService.setRepeatType(PlaybackService.REPEAT_NONE);
+                break;
+        }
+    }
+
+    public void initShuffle(){
+        mShuffle.setCompoundDrawablesWithIntrinsicBounds(0,
+                mService.isShuffling()
+                        ? R.drawable.ic_shuffle_on
+                        : UiTools.getResourceFromAttribute(mActivity, R.attr.ic_shuffle),
+                0, 0);
+
+    }
+
     private void initChapters() {
         final MediaPlayer.Chapter[] chapters = mService.getChapters(-1);
 
         int index = mService.getChapterIdx();
         if (chapters[index].name == null || chapters[index].name.equals(""))
-            mChaptersTitle.setText(getResources().getString(R.string.chapter) + " " + index);
+            mChaptersTitle.setText(String.format("%s %d", getResources().getString(R.string.chapter), index));
         else
             mChaptersTitle.setText(chapters[index].name);
     }
@@ -364,6 +428,14 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 mSpuDelay = tv;
                 initSpuDelay();
                 break;
+            case ID_REPEAT:
+                mRepeat = tv;
+                initRepeat();
+                break;
+            case ID_SHUFFLE:
+                mShuffle = tv;
+                initShuffle();
+                break;
         }
     }
 
@@ -416,32 +488,21 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             case ID_SAVE_PLAYLIST:
                 showFragment(ID_SAVE_PLAYLIST);
                 break;
+            case ID_REPEAT:
+                setRepeatMode();
+                break;
+            case ID_SHUFFLE:
+                mService.shuffle();
+                initShuffle();
+                break;
         }
     }
 
-    public boolean onLongClick (View v) {
-        switch (v.getId()) {
-            case ID_PLAYBACK_SPEED:
-                mService.setRate(1);
-                initPlaybackSpeed();
-                return true;
-            case ID_SPU_DELAY:
-                mService.setSpuDelay(0l);
-                initSpuDelay();
-                return true;
-            case ID_AUDIO_DELAY:
-                mService.setAudioDelay(0l);
-                initAudioDelay();
-                return true;
-        }
-        return false;
-    }
-
     @Override
     public void onFocusChange(View v, boolean hasFocus) {
         if (v instanceof TextView)
             ((TextView) v).setTextColor(v.hasFocus() ?
-                    getResources().getColor(R.color.orange300) : mTextColor);
+                    FOCUSED_TEXT_COLOR : mTextColor);
     }
 
 
@@ -478,27 +539,30 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
         int large_items = 0;
         boolean tvUi = VLCApplication.showTvUi();
 
-        mAdapter.addOption(new Option(ID_SLEEP, R.attr.ic_sleep_normal_style));
-        mAdapter.addOption(new Option(ID_PLAYBACK_SPEED, R.attr.ic_speed_normal_style));
-        mAdapter.addOption(new Option(ID_JUMP_TO, R.attr.ic_jumpto_normal_style));
+        mAdapter.addOption(new Option(ID_SLEEP, R.attr.ic_sleep_normal_style, getString(R.string.sleep_title)));
+        mAdapter.addOption(new Option(ID_PLAYBACK_SPEED, R.attr.ic_speed_normal_style, getString(R.string.playback_speed)));
+        mAdapter.addOption(new Option(ID_JUMP_TO, R.attr.ic_jumpto_normal_style, getString(R.string.jump_to_time)));
 
         if (mMode == MODE_VIDEO) {
             if (!tvUi)
-                mAdapter.addOption(new Option(ID_PLAY_AS_AUDIO, R.attr.ic_playasaudio_on));
-            mAdapter.addOption(new Option(ID_SPU_DELAY, R.attr.ic_subtitledelay));
-            mAdapter.addOption(new Option(ID_AUDIO_DELAY, R.attr.ic_audiodelay));
+                mAdapter.addOption(new Option(ID_PLAY_AS_AUDIO, R.attr.ic_playasaudio_on, getString(R.string.play_as_audio)));
+            mAdapter.addOption(new Option(ID_SPU_DELAY, R.attr.ic_subtitledelay, getString(R.string.spu_delay)));
+            mAdapter.addOption(new Option(ID_AUDIO_DELAY, R.attr.ic_audiodelay, getString(R.string.audio_delay)));
             if (!tvUi)
-                mAdapter.addOption(new Option(ID_POPUP_VIDEO, R.attr.ic_popup_dim));
+                mAdapter.addOption(new Option(ID_POPUP_VIDEO, R.attr.ic_popup_dim, getString(R.string.popup_playback_title)));
+            mAdapter.addOption(new Option(ID_REPEAT, R.attr.ic_repeat, getString(R.string.repeat_title)));
+            if (mService.canShuffle())
+                mAdapter.addOption(new Option(ID_SHUFFLE, R.attr.ic_shuffle, getString(R.string.shuffle_title)));
 
             final MediaPlayer.Chapter[] chapters = mService.getChapters(-1);
             final int chaptersCount = chapters != null ? chapters.length : 0;
             if (chaptersCount > 1) {
-                mAdapter.addOption(new Option(ID_CHAPTER_TITLE, R.attr.ic_chapter_normal_style));
+                mAdapter.addOption(new Option(ID_CHAPTER_TITLE, R.attr.ic_chapter_normal_style, getString(R.string.go_to_chapter)));
                 large_items++;
             }
         } else {
-            mAdapter.addOption(new Option(ID_EQUALIZER, R.attr.ic_equalizer_normal_style));
-            mAdapter.addOption(new Option(ID_SAVE_PLAYLIST, R.attr.ic_save));
+            mAdapter.addOption(new Option(ID_EQUALIZER, R.attr.ic_equalizer_normal_style, getString(R.string.equalizer)));
+            mAdapter.addOption(new Option(ID_SAVE_PLAYLIST, R.attr.ic_save, getString(R.string.playlist_save)));
         }
         setDialogDimensions(large_items);
     }
@@ -550,7 +614,7 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     private class AdvOptionsAdapter extends RecyclerView.Adapter<AdvOptionsAdapter.ViewHolder> {
 
         private ArrayList<Option> mList = new ArrayList<>();
-        private int mSelection = -1;
+        private int mSelection = 0;
 
         public AdvOptionsAdapter() {
             SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(AdvOptionsDialog.this.getContext());
@@ -563,7 +627,6 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             View v = LayoutInflater.from(parent.getContext())
                     .inflate(R.layout.adv_option_item, parent, false);
             v.setOnClickListener(AdvOptionsDialog.this);
-            v.setOnLongClickListener(AdvOptionsDialog.this);
             v.setOnFocusChangeListener(AdvOptionsDialog.this);
             return new ViewHolder(v);
         }
@@ -580,7 +643,6 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 tv.setCompoundDrawablesWithIntrinsicBounds(icon, 0, 0, 0);
             else
                 tv.setCompoundDrawablesWithIntrinsicBounds(0, icon, 0, 0);
-            tv.setText(option.text);
             setViewReference(option.id, tv);
         }
 
@@ -619,10 +681,17 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             mList.remove(opt);
         }
 
-        public class ViewHolder extends RecyclerView.ViewHolder {
+        public class ViewHolder extends RecyclerView.ViewHolder implements View.OnLongClickListener {
 
             public ViewHolder(View itemView) {
                 super(itemView);
+                itemView.setOnLongClickListener(this);
+            }
+
+            @Override
+            public boolean onLongClick(View view) {
+                Toast.makeText(VLCApplication.getAppContext(), mList.get(getAdapterPosition()).text, Toast.LENGTH_SHORT).show();
+                return true;
             }
         }
     }
@@ -631,10 +700,6 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
         int id, icon;
         String text;
 
-        Option(int id, int icon) {
-            this(id, icon, null);
-        }
-
         Option(int id, int icon, String text) {
             this.id = id;
             this.icon = icon;
