@@ -31,6 +31,7 @@ import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
 import android.widget.ImageView;
+import android.widget.LinearLayout;
 
 import org.videolan.vlc.BR;
 import org.videolan.vlc.R;
@@ -65,6 +66,7 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
     private boolean mListMode = false;
     private VideoGridFragment mFragment;
     private volatile ArrayList<MediaWrapper> mVideos = new ArrayList<>();
+    private ImageView mThumbnail;
 
     public VideoListAdapter(VideoGridFragment fragment) {
         super();
@@ -76,6 +78,14 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
         boolean listMode = viewType == TYPE_LIST;
         LayoutInflater inflater = (LayoutInflater) parent.getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
         View v = inflater.inflate(mListMode ? R.layout.video_list_card : R.layout.video_grid_card, parent, false);
+
+        if (!mListMode) {
+            mThumbnail = (ImageView) v.findViewById(R.id.ml_item_thumbnail);
+            int width = mFragment.mGridView.getColumnWidth();
+            int height = width*10/16;
+            mThumbnail.setLayoutParams(new LinearLayout.LayoutParams(width, height));
+        }
+
         return new ViewHolder(v, listMode);
     }
 
